==> libro-codemirror-0.1.7.tgz: package/es/mimetype.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
import { defaultMimeType } from '@difizen/libro-code-editor';
import { findBest, findByFileName } from "./mode.js";
var extname = function extname(path) {
  return path.split('.').pop();
};

/**
 * The mime type service for CodeMirror.
 */
export var CodeMirrorMimeTypeService = /*#__PURE__*/function () {
  function CodeMirrorMimeTypeService() {
    _classCallCheck(this, CodeMirrorMimeTypeService);
  }
  _createClass(CodeMirrorMimeTypeService, [{
    key: "getMimeTypeByLanguage",
    value:
    /**
     * Returns a mime type for the given language info.
     *
     * #### Notes
     * If a mime type cannot be found returns the default mime type `text/plain`, never `null`.
     */
    function getMimeTypeByLanguage(info) {
      var ext = info.file_extension || '';
      var mode = findBest(info.codemirror_mode || {
        mimetype: info.mimetype,
        name: info.name,
        ext: [ext.split('.').slice(-1)[0]]
      });
      return mode ? mode.mime : defaultMimeType;
    }

    /**
     * Returns a mime type for the given file path.
     *
     * #### Notes
     * If a mime type cannot be found returns the default mime type `text/plain`, never `null`.
     */
  }, {
    key: "getMimeTypeByFilePath",
    value: function getMimeTypeByFilePath(path) {
      var ext = extname(path);
      if (ext === '.ipy') {
        return 'text/x-python';
      } else if (ext === '.md') {
        return 'text/x-ipythongfm';
      }
      var mode = findByFileName(path) || findBest('');
      return mode ? mode.mime : defaultMimeType;
    }
  }]);
  return CodeMirrorMimeTypeService;
}();

==> libro-codemirror-0.2.2.tgz: package/es/mimetype.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
import { defaultMimeType } from '@difizen/libro-code-editor';
import { findBest, findByFileName } from "./mode.js";
var extname = function extname(path) {
  return path.split('.').pop();
};

/**
 * The mime type service for CodeMirror.
 */
export var CodeMirrorMimeTypeService = /*#__PURE__*/function () {
  function CodeMirrorMimeTypeService() {
    _classCallCheck(this, CodeMirrorMimeTypeService);
  }
  _createClass(CodeMirrorMimeTypeService, [{
    key: "getMimeTypeByLanguage",
    value:
    /**
     * Returns a mime type for the given language info.
     *
     * #### Notes
     * If a mime type cannot be found returns the default mime type `text/plain`, never `null`.
     */
    function getMimeTypeByLanguage(info) {
      var ext = info.file_extension || '';
      var mode = findBest(info.codemirror_mode || {
        mimetype: info.mimetype,
        name: info.name,
        ext: [ext.split('.').slice(-1)[0]]
      });
      return mode ? mode.mime : defaultMimeType;
    }

    /**
     * Returns a mime type for the given file path.
     *
     * #### Notes
     * If a mime type cannot be found returns the default mime type `text/plain`, never `null`.
     */
  }, {
    key: "getMimeTypeByFilePath",
    value: function getMimeTypeByFilePath(path) {
      var ext = extname(path);
      if (ext === '.ipy') {
        return 'text/x-python';
      } else if (ext === '.md') {
        return 'text/x-ipythongfm';
      }
      var mode = findByFileName(path) || findBest('');
      return mode ? mode.mime : defaultMimeType;
    }
  }]);
  return CodeMirrorMimeTypeService;
}();
